@@ -35,6 +35,7 @@ import org.pdfsam.module.ModuleDescriptor;
 import org.pdfsam.module.ModuleInputOutputType;
 import org.pdfsam.module.ModulePriority;
 import org.pdfsam.module.RequiredPdfData;
+import org.pdfsam.ui.commons.ClearModuleEvent;
 import org.pdfsam.ui.io.BrowsableOutputDirectoryField;
 import org.pdfsam.ui.io.PdfDestinationPane;
 import org.pdfsam.ui.module.BaseTaskExecutionModule;
@@ -44,6 +45,7 @@ import org.pdfsam.ui.module.RunButton;
 import org.pdfsam.ui.prefix.PrefixPane;
 import org.pdfsam.ui.selection.single.TaskParametersBuilderSingleSelectionPane;
 import org.pdfsam.ui.support.Views;
+import org.sejda.eventstudio.annotation.EventListener;
 import org.sejda.eventstudio.annotation.EventStation;
 import org.sejda.injector.Auto;
 import org.sejda.injector.Components;
@@ -138,6 +140,7 @@ public class SplitByBookmarksModule extends BaseTaskExecutionModule {
         prefix.addMenuItemFor(Prefix.FILENUMBER);
         prefix.addMenuItemFor(Prefix.BOOKMARK);
         prefix.addMenuItemFor(Prefix.BOOKMARK_STRICT);
+        prefix.addMenuItemFor("[TOTAL_FILESNUMBER]");
 
         pane.getChildren().addAll(selectionPane,
                 Views.titledPane(DefaultI18nContext.getInstance().i18n("Split settings"), splitOptions),
@@ -152,6 +155,15 @@ public class SplitByBookmarksModule extends BaseTaskExecutionModule {
         return MODULE_ID;
     }
 
+    @EventListener
+    public void onClearModule(ClearModuleEvent e) {
+        if (e.clearEverything) {
+            splitOptions.resetView();
+            prefix.resetView();
+            destinationPane.resetView();
+        }
+    }
+
     @Override
     public RequiredPdfData[] requires() {
         return new RequiredPdfData[] { RequiredPdfData.DEFAULT, RequiredPdfData.BOOMARKS };
