@@ -34,6 +34,7 @@ import org.pdfsam.module.ModuleCategory;
 import org.pdfsam.module.ModuleDescriptor;
 import org.pdfsam.module.ModuleInputOutputType;
 import org.pdfsam.module.ModulePriority;
+import org.pdfsam.ui.commons.ClearModuleEvent;
 import org.pdfsam.ui.io.BrowsableOutputDirectoryField;
 import org.pdfsam.ui.io.PdfDestinationPane;
 import org.pdfsam.ui.module.BaseTaskExecutionModule;
@@ -43,6 +44,7 @@ import org.pdfsam.ui.module.RunButton;
 import org.pdfsam.ui.prefix.PrefixPane;
 import org.pdfsam.ui.selection.single.TaskParametersBuilderSingleSelectionPane;
 import org.pdfsam.ui.support.Views;
+import org.sejda.eventstudio.annotation.EventListener;
 import org.sejda.eventstudio.annotation.EventStation;
 import org.sejda.injector.Auto;
 import org.sejda.injector.Components;
@@ -132,6 +134,7 @@ public class SplitBySizeModule extends BaseTaskExecutionModule {
                 prefix);
         prefix.addMenuItemFor(Prefix.CURRENTPAGE);
         prefix.addMenuItemFor(Prefix.FILENUMBER);
+        prefix.addMenuItemFor("[TOTAL_FILESNUMBER]");
 
         pane.getChildren().addAll(selectionPane,
                 Views.titledPane(DefaultI18nContext.getInstance().i18n("Split settings"), splitOptions),
@@ -151,6 +154,15 @@ public class SplitBySizeModule extends BaseTaskExecutionModule {
         return new ImageView("split_by_size.png");
     }
 
+    @EventListener
+    public void onClearModule(ClearModuleEvent e) {
+        if (e.clearEverything) {
+            splitOptions.resetView();
+            prefix.resetView();
+            destinationPane.resetView();
+        }
+    }
+
     @Components({ SplitBySizeModule.class })
     public static class ModuleConfig {
         @Provides
